@@ -6,9 +6,10 @@ import abc
 import copy
 import itertools
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union, cast
 
 import numpy as np
+import numpy.typing as npt
 import pandas as pd
 import scipy.stats
 from future.utils import with_metaclass
@@ -58,8 +59,8 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         self._top_k_modes: int = 5  # By default, return at max 5 modes
         self.sum: Union[int, float] = 0
         self._biased_variance: float = np.nan
-        self._biased_skewness: float = np.nan
-        self._biased_kurtosis: float = np.nan
+        self._biased_skewness: Union[float, np.float64] = np.nan
+        self._biased_kurtosis: Union[float, np.float64] = np.nan
         self._median_is_enabled: bool = True
         self._median_abs_dev_is_enabled: bool = True
         self.max_histogram_bin: int = 100000
@@ -123,6 +124,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
             "num_zeros": NumericStatsMixin._get_num_zeros,
             "num_negatives": NumericStatsMixin._get_num_negatives,
         }
+        self.match_count: int  # needed for mypy
 
         self._filter_properties_w_options(self.__calculations, options)
 
@@ -377,7 +379,8 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
             "median": utils.find_diff_of_numbers(self.median, other_profile.median),
             "mode": utils.find_diff_of_lists_and_sets(self.mode, other_profile.mode),
             "median_absolute_deviation": utils.find_diff_of_numbers(
-                self.median_abs_deviation, other_profile.median_abs_deviation
+                self.median_abs_deviation,
+                other_profile.median_abs_deviation,
             ),
             "variance": utils.find_diff_of_numbers(
                 self.variance, other_profile.variance
@@ -391,6 +394,12 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
                 other_profile.variance,
                 other_profile.match_count,
             ),
+            "psi": self._calculate_psi(
+                self.match_count,
+                self._stored_histogram["histogram"],
+                other_profile.match_count,
+                other_profile._stored_histogram["histogram"],
+            ),
         }
         return differences
 
@@ -398,7 +407,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
     def mean(self) -> float:
         """Return mean value."""
         if self.match_count == 0:
-            return 0
+            return 0.0
         return float(self.sum) / self.match_count
 
     @property
@@ -435,14 +444,14 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         )
 
     @property
-    def stddev(self) -> float:
+    def stddev(self) -> Union[float, np.float64]:
         """Return stddev value."""
         if self.match_count == 0:
             return np.nan
-        return np.sqrt(self.variance)
+        return cast(np.float64, np.sqrt(self.variance))
 
     @property
-    def skewness(self) -> float:
+    def skewness(self) -> Union[float, np.float64]:
         """Return skewness value."""
         return (
             self._biased_skewness
@@ -451,7 +460,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         )
 
     @property
-    def kurtosis(self) -> float:
+    def kurtosis(self) -> Union[float, np.float64]:
         """Return kurtosis value."""
         return (
             self._biased_kurtosis
@@ -516,6 +525,151 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         results["welch"]["p-value"] = float(welch_p_val)
         return results
 
+    def _preprocess_for_calculate_psi(
+        self,
+        self_histogram,
+        other_histogram,
+    ):
+        new_self_histogram = {"bin_counts": None, "bin_edges": None}
+        new_other_histogram = {"bin_counts": None, "bin_edges": None}
+        regenerate_histogram = False
+        num_psi_bins = 10
+
+        if (
+            isinstance(self_histogram["bin_counts"], np.ndarray)
+            and isinstance(self_histogram["bin_edges"], np.ndarray)
+            and isinstance(other_histogram["bin_counts"], np.ndarray)
+            and isinstance(other_histogram["bin_edges"], np.ndarray)
+        ):
+            regenerate_histogram = True
+
+            # calculate the min of the first edge and
+            # the max of the last edge between two arrays
+            min_min_edge = min(
+                self_histogram["bin_edges"][0],
+                other_histogram["bin_edges"][0],
+            )
+            max_max_edge = max(
+                self_histogram["bin_edges"][-1],
+                other_histogram["bin_edges"][-1],
+            )
+
+            if min_min_edge == max_max_edge:
+                return 0, 0
+
+        if regenerate_histogram:
+            new_self_histogram["bin_counts"] = self_histogram["bin_counts"]
+            new_self_histogram["bin_edges"] = self_histogram["bin_edges"]
+            new_other_histogram["bin_edges"] = other_histogram["bin_edges"]
+            new_other_histogram["bin_counts"] = other_histogram["bin_counts"]
+
+            len_self_bin_counts = len(self_histogram["bin_counts"])
+
+            # re-calculate `self` histogram
+            if len_self_bin_counts != num_psi_bins:
+                histogram, hist_loss = self._regenerate_histogram(
+                    bin_counts=self_histogram["bin_counts"],
+                    bin_edges=self_histogram["bin_edges"],
+                    suggested_bin_count=num_psi_bins,
+                    options={
+                        "min_edge": min_min_edge,
+                        "max_edge": max_max_edge,
+                    },
+                )
+                new_self_histogram["bin_counts"] = histogram["bin_counts"]
+                new_self_histogram["bin_edges"] = histogram["bin_edges"]
+
+            # re-calculate `other_profile` histogram
+            histogram_edges_not_equal = False
+            all_array_values_equal = np.array_equal(
+                other_histogram["bin_edges"], self_histogram["bin_edges"]
+            )
+            if not all_array_values_equal:
+                histogram_edges_not_equal = True
+
+            if histogram_edges_not_equal:
+                histogram, hist_loss = self._regenerate_histogram(
+                    bin_counts=other_histogram["bin_counts"],
+                    bin_edges=other_histogram["bin_edges"],
+                    suggested_bin_count=num_psi_bins,
+                    options={
+                        "min_edge": min_min_edge,
+                        "max_edge": max_max_edge,
+                    },
+                )
+
+                new_other_histogram["bin_edges"] = histogram["bin_edges"]
+                new_other_histogram["bin_counts"] = histogram["bin_counts"]
+
+        return new_self_histogram, new_other_histogram
+
+    def _calculate_psi(
+        self,
+        self_match_count: int,
+        self_histogram: np.ndarray,
+        other_match_count: int,
+        other_histogram: np.ndarray,
+    ) -> Optional[float]:
+        """
+        Calculate PSI (Population Stability Index).
+
+        ```
+        PSI = SUM((other_pcnt - self_pcnt) * ln(other_pcnt / self_pcnt))
+        ```
+
+        PSI Breakpoint Thresholds:
+            - PSI < 0.1: no significant population change
+            - 0.1 < PSI < 0.2: moderate population change
+            - PSI >= 0.2: significant population change
+
+        :param self_match_count: self.match_count
+        :type self_match_count: int
+        :param self_histogram: self._stored_histogram["histogram"]
+        :type self_histogram: np.ndarray
+        :param self_match_count: other_profile.match_count
+        :type self_match_count: int
+        :param other_histogram: other_profile._stored_histogram["histogram"]
+        :type other_histogram: np.ndarray
+        :return: psi_value
+        :rtype: optional[float]
+        """
+        psi_value = 0
+
+        new_self_histogram, new_other_histogram = self._preprocess_for_calculate_psi(
+            self_histogram=self_histogram,
+            other_histogram=other_histogram,
+        )
+
+        if new_self_histogram == 0 and new_other_histogram == 0:
+            return 0.0
+
+        if isinstance(new_other_histogram["bin_edges"], type(None)) or isinstance(
+            new_self_histogram["bin_edges"], type(None)
+        ):
+            warnings.warn(
+                "No edges available in at least one histogram for calculating `PSI`",
+                RuntimeWarning,
+            )
+            return None
+
+        bin_count: int = 0  # required typing by mypy
+        for iter_value, bin_count in enumerate(new_self_histogram["bin_counts"]):
+
+            self_percent = bin_count / self_match_count
+            other_percent = (
+                new_other_histogram["bin_counts"][iter_value] / other_match_count
+            )
+            if (self_percent == other_percent) and self_percent == 0:
+                continue
+
+            iter_psi = (other_percent - self_percent) * np.log(
+                other_percent / self_percent
+            )
+            if iter_psi and iter_psi != float("inf"):
+                psi_value += iter_psi
+
+        return psi_value
+
     def _update_variance(
         self, batch_mean: float, batch_var: float, batch_count: int
     ) -> float:
@@ -594,14 +748,14 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
     @staticmethod
     def _merge_biased_skewness(
         match_count1: int,
-        biased_skewness1: float,
+        biased_skewness1: Union[float, np.float64],
         biased_variance1: float,
         mean1: float,
         match_count2: int,
-        biased_skewness2: float,
+        biased_skewness2: Union[float, np.float64],
         biased_variance2: float,
         mean2: float,
-    ) -> float:
+    ) -> Union[float, np.float64]:
         """
         Calculate the combined skewness of two data chunks.
 
@@ -645,11 +799,13 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         third_term = 3 * delta * (match_count1 * M2_2 - match_count2 * M2_1) / N
         M3 = first_term + second_term + third_term
 
-        biased_skewness = np.sqrt(N) * M3 / np.sqrt(M2**3)
+        biased_skewness: np.float64 = np.sqrt(N) * M3 / np.sqrt(M2**3)
         return biased_skewness
 
     @staticmethod
-    def _correct_bias_skewness(match_count: int, biased_skewness: float) -> float:
+    def _correct_bias_skewness(
+        match_count: int, biased_skewness: Union[float, np.float64]
+    ) -> Union[float, np.float64]:
         """
         Apply bias correction to skewness.
 
@@ -667,7 +823,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
             )
             return np.nan
 
-        skewness = (
+        skewness: np.float64 = (
             np.sqrt(match_count * (match_count - 1))
             * biased_skewness
             / (match_count - 2)
@@ -677,16 +833,16 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
     @staticmethod
     def _merge_biased_kurtosis(
         match_count1: int,
-        biased_kurtosis1: float,
-        biased_skewness1: float,
+        biased_kurtosis1: Union[float, np.float64],
+        biased_skewness1: Union[float, np.float64],
         biased_variance1: float,
         mean1: float,
         match_count2: int,
-        biased_kurtosis2: float,
-        biased_skewness2: float,
+        biased_kurtosis2: Union[float, np.float64],
+        biased_skewness2: Union[float, np.float64],
         biased_variance2: float,
         mean2: float,
-    ) -> float:
+    ) -> Union[float, np.float64]:
         """
         Calculate the combined kurtosis of two sets of data.
 
@@ -716,10 +872,10 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         M2_2 = match_count2 * biased_variance2
         M2 = M2_1 + M2_2 + delta**2 * match_count1 * match_count2 / N
         if not M2:
-            return 0
+            return 0.0
 
-        M3_1 = biased_skewness1 * np.sqrt(M2_1**3) / np.sqrt(match_count1)
-        M3_2 = biased_skewness2 * np.sqrt(M2_2**3) / np.sqrt(match_count2)
+        M3_1: np.float64 = biased_skewness1 * np.sqrt(M2_1**3) / np.sqrt(match_count1)
+        M3_2: np.float64 = biased_skewness2 * np.sqrt(M2_2**3) / np.sqrt(match_count2)
         M4_1 = (biased_kurtosis1 + 3) * M2_1**2 / match_count1
         M4_2 = (biased_kurtosis2 + 3) * M2_2**2 / match_count2
 
@@ -742,11 +898,13 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         fourth_term = 4 * delta * (match_count1 * M3_2 - match_count2 * M3_1) / N
         M4 = first_term + second_term + third_term + fourth_term
 
-        biased_kurtosis = N * M4 / M2**2 - 3
+        biased_kurtosis: np.float64 = N * M4 / M2**2 - 3
         return biased_kurtosis
 
     @staticmethod
-    def _correct_bias_kurtosis(match_count: int, biased_kurtosis: float) -> float:
+    def _correct_bias_kurtosis(
+        match_count: int, biased_kurtosis: Union[float, np.float64]
+    ) -> Union[float, np.float64]:
         """
         Apply bias correction to kurtosis.
 
@@ -800,18 +958,18 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
                 count += 1
         highest_idxs = np.array(highest_idxs)  # type: ignore
 
-        mode = (
+        mode: npt.NDArray[np.float64] = (
             bin_edges[highest_idxs] + bin_edges[highest_idxs + 1]  # type: ignore
         ) / 2
-        return mode.tolist()
+        return cast(List[float], mode.tolist())
 
-    def _estimate_stats_from_histogram(self) -> float:
+    def _estimate_stats_from_histogram(self) -> np.float64:
         # test estimated mean and var
         bin_counts = self._stored_histogram["histogram"]["bin_counts"]
         bin_edges = self._stored_histogram["histogram"]["bin_edges"]
         mids = 0.5 * (bin_edges[1:] + bin_edges[:-1])
         mean = np.average(mids, weights=bin_counts)
-        var = np.average((mids - mean) ** 2, weights=bin_counts)
+        var: np.float64 = np.average((mids - mean) ** 2, weights=bin_counts)
         return var
 
     def _total_histogram_bin_variance(
@@ -858,7 +1016,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         # reset the edge
         bin_edges[-1] = temp_last_edge
 
-        sum_error = sum(
+        sum_error: float = sum(
             (input_array - (bin_edges[inds] + bin_edges[inds - 1]) / 2) ** 2
         )
 
@@ -943,7 +1101,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         if not hist_to_array:
             hist_to_array = [[]]
 
-        array_flatten = np.concatenate(
+        array_flatten: np.ndarray = np.concatenate(
             (
                 hist_to_array
                 + [[bin_edges[-2]] * int(bin_counts[-1] / 2)]
@@ -1059,48 +1217,19 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         self._stored_histogram["current_loss"] = histogram_loss
         self._stored_histogram["total_loss"] += histogram_loss
 
-    def _histogram_for_profile(
-        self, histogram_method: str
+    def _regenerate_histogram(
+        self, bin_counts, bin_edges, suggested_bin_count, options=None
     ) -> Tuple[Dict[str, np.ndarray], float]:
-        """
-        Convert the stored histogram into the presentable state.
-
-        Based on the suggested histogram bin count from numpy.histograms.
-        The bin count used is stored in 'suggested_bin_count' for each method.
-
-        :param histogram_method: method to use for determining the histogram
-            profile
-        :type histogram_method: str
-        :return: histogram bin edges and bin counts
-        :rtype: dict
-        """
-        bin_counts, bin_edges = (
-            self._stored_histogram["histogram"]["bin_counts"],
-            self._stored_histogram["histogram"]["bin_edges"],
-        )
-
-        current_bin_counts, suggested_bin_count = (
-            self.histogram_methods[histogram_method]["histogram"]["bin_counts"],
-            self.histogram_methods[histogram_method]["suggested_bin_count"],
-        )
-
-        # base case, no need to change if it is already correct
-        if not self._has_histogram or current_bin_counts is not None:
-            return (
-                self.histogram_methods[histogram_method]["histogram"],
-                self.histogram_methods[histogram_method]["total_loss"],
-            )
-        elif len(bin_counts) == suggested_bin_count:
-            return (
-                self._stored_histogram["histogram"],
-                self._stored_histogram["total_loss"],
-            )
 
         # create proper binning
         new_bin_counts = np.zeros((suggested_bin_count,))
         new_bin_edges = np.linspace(
             bin_edges[0], bin_edges[-1], suggested_bin_count + 1
         )
+        if options:
+            new_bin_edges = np.linspace(
+                options["min_edge"], options["max_edge"], suggested_bin_count + 1
+            )
 
         # allocate bin_counts
         new_bin_id = 0
@@ -1159,6 +1288,49 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
 
         return ({"bin_edges": new_bin_edges, "bin_counts": new_bin_counts}, hist_loss)
 
+    def _histogram_for_profile(
+        self, histogram_method: str
+    ) -> Tuple[Dict[str, np.ndarray], float]:
+        """
+        Convert the stored histogram into the presentable state.
+
+        Based on the suggested histogram bin count from numpy.histograms.
+        The bin count used is stored in 'suggested_bin_count' for each method.
+
+        :param histogram_method: method to use for determining the histogram
+            profile
+        :type histogram_method: str
+        :return: histogram bin edges and bin counts
+        :rtype: dict
+        """
+        bin_counts, bin_edges = (
+            self._stored_histogram["histogram"]["bin_counts"],
+            self._stored_histogram["histogram"]["bin_edges"],
+        )
+
+        current_bin_counts, suggested_bin_count = (
+            self.histogram_methods[histogram_method]["histogram"]["bin_counts"],
+            self.histogram_methods[histogram_method]["suggested_bin_count"],
+        )
+
+        # base case, no need to change if it is already correct
+        if not self._has_histogram or current_bin_counts is not None:
+            return (
+                self.histogram_methods[histogram_method]["histogram"],
+                self.histogram_methods[histogram_method]["total_loss"],
+            )
+        elif len(bin_counts) == suggested_bin_count:
+            return (
+                self._stored_histogram["histogram"],
+                self._stored_histogram["total_loss"],
+            )
+
+        return self._regenerate_histogram(
+            bin_counts=bin_counts,
+            bin_edges=bin_edges,
+            suggested_bin_count=suggested_bin_count,
+        )
+
     def _get_best_histogram_for_profile(self) -> Dict:
         """
         Convert the stored histogram into the presentable state.
@@ -1180,7 +1352,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
                     self.histogram_selection = method
                     best_hist_loss = hist_loss
 
-        return self.histogram_methods[self.histogram_selection]["histogram"]
+        return cast(Dict, self.histogram_methods[self.histogram_selection]["histogram"])
 
     def _get_percentile(
         self, percentiles: Union[np.ndarray, List[float]]
@@ -1220,7 +1392,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         )
         if median_value:
             quantiles[percentiles == 50] = median_value
-        return quantiles.tolist()
+        return cast(List[float], quantiles.tolist())
 
     @staticmethod
     def _fold_histogram(
@@ -1281,7 +1453,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         return [bin_counts_pos, bin_edges_pos], [bin_counts_neg, bin_edges_neg]
 
     @property
-    def median_abs_deviation(self) -> float:
+    def median_abs_deviation(self) -> Union[float, np.float64]:
         """
         Get median absolute deviation estimated from the histogram of the data.
 
@@ -1315,7 +1487,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
         # if all bin edges are positive or negative (no break point),
         # the median value is actually 0
         if len(bin_counts_pos) == 0 or len(bin_counts_neg) == 0:
-            return 0
+            return 0.0
 
         # otherwise, superimpose the two histogram and interpolate
         # the median at cumsum count 0.5
@@ -1334,19 +1506,25 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
             np.append([True], np.diff(bin_edges_impose) > 1e-14)
         ]
 
-        bin_counts_impose_pos: float = np.interp(
-            bin_edges_impose, bin_edges_pos, np.cumsum(np.append([0], bin_counts_pos))
+        bin_counts_impose_pos: npt.NDArray[np.float64] = np.interp(
+            bin_edges_impose,
+            bin_edges_pos,
+            np.cumsum(np.append([0], bin_counts_pos)),
         )
-        bin_counts_impose_neg: float = np.interp(
-            bin_edges_impose, bin_edges_neg, np.cumsum(np.append([0], bin_counts_neg))
+        bin_counts_impose_neg: npt.NDArray[np.float64] = np.interp(
+            bin_edges_impose,
+            bin_edges_neg,
+            np.cumsum(np.append([0], bin_counts_neg)),
+        )
+        bin_counts_impose: npt.NDArray[np.float64] = (
+            bin_counts_impose_pos + bin_counts_impose_neg
         )
-        bin_counts_impose = bin_counts_impose_pos + bin_counts_impose_neg
 
         median_inds = np.abs(bin_counts_impose - 0.5) < 1e-10
         if np.sum(median_inds) > 1:
-            return np.mean(bin_edges_impose[median_inds])
+            return cast(np.float64, np.mean(bin_edges_impose[median_inds]))
 
-        return np.interp(0.5, bin_counts_impose, bin_edges_impose)
+        return cast(np.float64, np.interp(0.5, bin_counts_impose, bin_edges_impose))
 
     def _get_quantiles(self) -> None:
         """
@@ -1670,7 +1848,7 @@ class NumericStatsMixin(with_metaclass(abc.ABCMeta, object)):  # type: ignore
             return a == b
 
     @staticmethod
-    def np_type_to_type(val: Any) -> Union[int, float]:
+    def np_type_to_type(val: Any) -> Any:
         """
         Convert numpy variables to base python type variables.
 
