@@ -1689,7 +1689,7 @@ class TestFloatColumn(unittest.TestCase):
             "precision": {
                 "min": 1,
                 "max": 1,
-                "mean": 1,
+                "mean": 1.0,
                 "var": profile1["precision"]["var"] - profile2["precision"]["var"],
                 "std": profile1["precision"]["std"] - profile2["precision"]["std"],
                 "sample_size": -1,
@@ -1698,9 +1698,10 @@ class TestFloatColumn(unittest.TestCase):
             },
             "t-test": {
                 "t-statistic": 0.5393164101529813,
-                "conservative": {"df": 2, "p-value": 0.643676756587475},
+                "conservative": {"df": 2.0, "p-value": 0.643676756587475},
                 "welch": {"df": 4.999127432888682, "p-value": 0.6128117908944144},
             },
+            "psi": 0,
         }
         profile_diff = profiler1.diff(profiler2)
         try:
