@@ -796,6 +796,7 @@ class TestNumericStatsMixin(unittest.TestCase):
                 "conservative": {"df": 9, "p-value": 0.7039643545772609},
                 "welch": {"df": 25.945257024943864, "p-value": 0.6980401261750298},
             },
+            "psi": None,
         }
 
         difference = other1.diff(other2)
@@ -836,6 +837,7 @@ class TestNumericStatsMixin(unittest.TestCase):
                 "conservative": {"df": None, "p-value": None},
                 "welch": {"df": None, "p-value": None},
             },
+            "psi": None,
         }
         expected_var = expected_diff.pop("variance")
         expected_stddev = expected_diff.pop("stddev")
@@ -885,6 +887,7 @@ class TestNumericStatsMixin(unittest.TestCase):
                 "conservative": {"df": None, "p-value": None},
                 "welch": {"df": None, "p-value": None},
             },
+            "psi": None,
         }
         expected_var = expected_diff.pop("variance")
         expected_stddev = expected_diff.pop("stddev")
@@ -933,6 +936,7 @@ class TestNumericStatsMixin(unittest.TestCase):
                 "conservative": {"df": None, "p-value": None},
                 "welch": {"df": None, "p-value": None},
             },
+            "psi": None,
         }
         expected_var = expected_diff.pop("variance")
         expected_stddev = expected_diff.pop("stddev")
@@ -980,6 +984,7 @@ class TestNumericStatsMixin(unittest.TestCase):
                 "conservative": {"df": 9, "p-value": 0.011958658754358975},
                 "welch": {"df": 25.945257024943864, "p-value": 0.004201616692122823},
             },
+            "psi": None,
         }
         difference = other1.diff(other2)
         self.assertDictEqual(expected_diff, difference)
@@ -991,3 +996,106 @@ class TestNumericStatsMixin(unittest.TestCase):
             str(exc.exception),
             "Unsupported operand type(s) for diff: 'TestColumnWProps' and" " 'str'",
         )
+
+        # PSI same distribution test
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
+        other1.match_count = 55
+        other1._stored_histogram = {
+            "total_loss": 0,
+            "current_loss": 0,
+            "suggested_bin_count": 10,
+            "histogram": {
+                "bin_counts": np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]),
+                "bin_edges": np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]),
+            },
+        }
+
+        other2.match_count = 550
+        other2._stored_histogram = {
+            "total_loss": 0,
+            "current_loss": 0,
+            "suggested_bin_count": 10,
+            "histogram": {
+                "bin_counts": np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]) * 10,
+                "bin_edges": np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]),
+            },
+        }
+
+        expected_psi_value = 0
+        psi_value = other1._calculate_psi(
+            self_match_count=other1.match_count,
+            self_histogram=other1._stored_histogram["histogram"],
+            other_match_count=other2.match_count,
+            other_histogram=other2._stored_histogram["histogram"],
+        )
+        self.assertEquals(expected_psi_value, psi_value)
+
+        # PSI min_min_edge == max_max_edge
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
+        other1.match_count = 10
+        other1._stored_histogram = {
+            "total_loss": 0,
+            "current_loss": 0,
+            "suggested_bin_count": 10,
+            "histogram": {"bin_counts": np.array([10]), "bin_edges": np.array([1, 1])},
+        }
+
+        other2.match_count = 20
+        other2._stored_histogram = {
+            "total_loss": 0,
+            "current_loss": 0,
+            "suggested_bin_count": 10,
+            "histogram": {"bin_counts": np.array([20]), "bin_edges": np.array([1, 1])},
+        }
+
+        expected_psi_value = 0
+        psi_value = other1._calculate_psi(
+            self_match_count=other1.match_count,
+            self_histogram=other1._stored_histogram["histogram"],
+            other_match_count=other2.match_count,
+            other_histogram=other2._stored_histogram["histogram"],
+        )
+        self.assertEquals(expected_psi_value, psi_value)
+
+        # PSI regen other / not self
+        other1, other2 = TestColumnWProps(), TestColumnWProps()
+        other1.match_count = 55
+        other1._stored_histogram = {
+            "total_loss": 0,
+            "current_loss": 0,
+            "suggested_bin_count": 10,
+            "histogram": {
+                "bin_counts": np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]),
+                "bin_edges": np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]),
+            },
+        }
+
+        other2.match_count = 20
+        other2._stored_histogram = {
+            "total_loss": 0,
+            "current_loss": 0,
+            "suggested_bin_count": 10,
+            "histogram": {
+                "bin_counts": np.array([5, 5, 10]),
+                "bin_edges": np.array([1, 3, 5, 7]),
+            },
+        }
+
+        expected_psi_value = 0.6617899380349177
+        psi_value = other1._calculate_psi(
+            self_match_count=other1.match_count,
+            self_histogram=other1._stored_histogram["histogram"],
+            other_match_count=other2.match_count,
+            other_histogram=other2._stored_histogram["histogram"],
+        )
+        self.assertEquals(expected_psi_value, psi_value)
+
+        # PSI regen self / not other
+        expected_psi_value = 0.6617899380349177
+        psi_value = other1._calculate_psi(
+            self_match_count=other2.match_count,
+            self_histogram=other2._stored_histogram["histogram"],
+            other_match_count=other1.match_count,
+            other_histogram=other1._stored_histogram["histogram"],
+        )
+        self.assertEquals(expected_psi_value, psi_value)
